@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic::Role::Help;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '1.59'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '1.60'; # VERSION
 
 # split here just so it's more organized
 
@@ -68,14 +68,18 @@ sub _help_add_row {
 
     $t->add_row($row);
 
-    for (0..@{$t->{columns}}-1) {
-        my %styles = (formats=>[]);
-        push @{ $styles{formats} },
-            [wrap=>{ansi=>1, mb=>1, width=>$t->{cell_width}-$indent*2}]
+    my $dux_available = eval { require Data::Unixish; 1 } && !$@;
+
+    if ($dux_available) {
+        for (0..@{$t->{columns}}-1) {
+            my %styles = (formats=>[]);
+            push @{ $styles{formats} },
+                [wrap=>{ansi=>1, mb=>1, width=>$t->{cell_width}-$indent*2}]
                 if $wrap;
-        push @{ $styles{formats} }, [lins=>{text=>"  " x $indent}]
-            if $indent && $_ == 0;
-        $t->set_cell_style($rownum, $_, \%styles);
+            push @{ $styles{formats} }, [lins=>{text=>"  " x $indent}]
+                if $indent && $_ == 0;
+            $t->set_cell_style($rownum, $_, \%styles);
+        }
     }
 }
 
@@ -511,7 +515,7 @@ Perinci::CmdLine::Classic::Role::Help - Help-related routines
 
 =head1 VERSION
 
-This document describes version 1.59 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-29.
+This document describes version 1.60 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-10-20.
 
 =for Pod::Coverage ^(.+)$
 
